@@ -454,7 +454,7 @@ class ChainedAssignment:
         pd.options.mode.chained_assignment = self.saved_swcw
 
 @contextmanager
-def HiddenPrints(hidden=True):
+def HiddenPrints():
     '''
     Context manager to temporarily disable printing. Source: https://stackoverflow.com/a/52442331/17333120. Usage:
         with HiddenPrints():
@@ -462,10 +462,9 @@ def HiddenPrints(hidden=True):
         with HiddenPrints(False):
             --code with printing--
     '''
-    if hidden:
-        with open(devnull, 'w') as fnull:
-            with redirect_stderr(fnull) as err, redirect_stdout(fnull) as out:
-                yield (err, out)
+    with open(devnull, 'w') as fnull:
+        with redirect_stderr(fnull) as err, redirect_stdout(fnull) as out:
+            yield (err, out)
 
 loggers = {}
 
